@@ -1,4 +1,4 @@
-# Copyrights 2010-2014 by [Mark Overmeer].
+# Copyrights 2010-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -6,7 +6,8 @@ use warnings;
 use strict;
 
 package XML::eXistDB::RPC;
-our $VERSION = '0.13';
+use vars '$VERSION';
+$VERSION = '0.14';
 
 
 use Log::Report 'xml-existdb', syntax => 'LONG';
@@ -47,7 +48,7 @@ sub init($)
       = defined $args->{compress_upload} ? $args->{compress_upload} : 128;
     $self->{chunks}  = defined $args->{chunk_size} ? $args->{chunk_size} : 32;
 
-    $self->login($args->{user} || 'guest', $args->{password} || 'guest');
+    $self->login($args->{user} // 'guest', $args->{password} // 'guest');
     $self->{pp_up}   = $args->{prettyprint_upload} ? 1 : 0;
     $self->{schemas} = $args->{schemas};
 
